@@ -220,6 +220,7 @@ define ([
                 // console.log("arr has " + len + " members and the first one has text " + arr[0].text)
             } else {
                 console.log("CRITICAL ERROR: in maxLength(), arr has no members");
+                return null;
             }
             max = arr.reduce(function(prevVal, elem) {
                 if (elem.text === null || elem.text === undefined || elem.hidden === true) {
@@ -290,6 +291,22 @@ define ([
             return obj[prop];
         }, // valueToDisplay
 
+        vetEntries = function (tgt, arr) {
+            // checks that all entries do exist
+            // if any are missing, write an error
+            // return true (OK) or false (NOT OK)
+            for (var i = 0; i < arr.length; i += 1) {
+                if (typeof arr[i] !== "object" ||
+                    arr[i] === null ||
+                    arr[i].text === undefined)
+                {
+                    console.log("CRITICAL ERROR: target definition ->" + tgt + "<- mentions non-existent entry");
+                    return false;
+                }
+            }
+            return true;
+        }, // vetEntries
+
         // "Your choice" section at the bottom - shared by all target types
         yourChoice = function () {
             return '<br><b>Your choice:</b> <input name="sel" size=3 maxlength=2> ' +
@@ -360,6 +377,10 @@ define ([
                 // determine characters needed for padding (based on longest
                 // entry)
                 allEntries = dbo.getEntries();
+                if (! vetEntries(dbn, allEntries)) {
+                    // no point in going any further
+                    return null;
+                }
                 needed = maxLength(allEntries) + 2;
 
                 // display entries
@@ -436,6 +457,10 @@ define ([
                     );
                 }
                 // console.log("About to call maxLength() on allEntries", allEntries);
+                if (! vetEntries(dfn, allEntries)) {
+                    // no point in going any further
+                    return null;
+                }
                 needed = maxLength(allEntries) + 2;
 
                 // READ-ONLY entries first
@@ -574,8 +599,9 @@ define ([
         logout: function () {
             var r = '';
             r += '<br><br><br>';
-            r += 'You have been logged out of our humble application<br><br>';
-            r += 'Have a lot of fun!<br><br><br>';
+            r += 'You have logged out of this humble application<br><br>';
+            r += 'If you\'d like to log back in, just reload the page by pressing F5 or Ctrl-R<br><br>';
+            r += 'Have a lot of fun!<br><br><br><br>';
             return r;
         } // logout
 
